#ifndef __WMCONFIG_H
#define __WMCONFIG_H

extern bool configurationNeeded;

void loadConfiguration(const char *fileName);
void loadThemeConfiguration(const char *themeName);
void addWorkspace(const char *name, const char *value, bool append);
void setLook(const char *name, const char *value, bool append);
void freeConfiguration();
int setDefault(const char *basename, const char *config);

#endif
